/* migstat05_sas.zip: 03 Grundtypisierung MigH 2005.sas

                                 
SAS-PROGRAMME ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2005 

Programmautor/en:
SAS-Originalprogramme: Gunter Brueckner (Statistisches Bundesamt;
             Referat F 204 Migration und integration, Wohnen);
Anpassungen an Scientific Use File Mikrozensus 2005: 
	     Delia Jaeger, Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck:      						       
   Diese Programmreihe dient der Replikation des Migrationsstatus und der 
   Staatsangehoerigkeit zum Migrationsstatus im Scientific Use File (SUF) 
   des Mikrozensus 2005.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus 
   des Statistischen Bundesamtes und wurden an Recodierungen des SUF 
   angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit nur rudimentaer vorhanden sind (s. u.). Die 
   Replikation ist deshalb nur mit Abweichungen moeglich. 
  
Weiterfuehrende Programmbeschreibung:                                
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des       
   Migrationshintergrundes in den Mikrozensus Scientific-Use-Files    
   2005-2009. GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS.    
   URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
        gesis_reihen/gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf
Download dieser Datei:                                               
   http://www.gesis.org/missy/fileadmin/missy/daten/mikrodaten_tools/ 
   migstat05_sas.zip                                              
Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf        
   dem Weg zu einer definitorischen Abgrenzung - S. 398-407 in:       
Statistisches Bundesamt, 2011: Bevoelkerung mit Migrationshintergrund.
   Ergebnisse des Mikrozensus 2009. Fachserie 1 Reihe 2.2. Wiesbaden. 
URL: https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob= 
   publicationFile; letzter Zugriff: 24.07.2012
 
Programmstruktur:
0. Datenvorbereitung: 03 Grundtypisierung MigH 2005.sas
1. Grundtypisierung des Migationshintergrundes: 03 Grundtypisierung MigH 2005.sas
2. Identifikation von 3-Generationen-Haushalten: 05 Grosseltern-Eltern 2005.sas
3. Endtypisierung der Grosseltern: 06 Endtypisierung Grosseltern 2005.sas
4. Endtypisierung der Eltern: 07 Endtypisierung Eltern 2005.sas
5. Endtypisierung Befragte: 08 Endtypisierung Befragte 2005.sas
6. Umsetzung von Zeitreihenkompatibilitaet: 09 Zeitreihenkompatibilitaet 2005.sas
7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse: 09 Zeitreihenkompatibilitaet 2005.sas

Programmstatus:
  Getestet mit SAS 9.1 for Windows und Scientific Use File Mikrozensus 2005, 
  Version 3, Stand: Juli 2012.
*/


/* 
  0. Datenvorbereitung */

OPTIONS NOFMTERR; RUN;   /* ohne Formate */

/* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */
libname mzjahr '<Arbeitsverzeichnis>';


data mzjahr.MZTypisiert (KEEP=EF1 EF3 EF4 EF5 EF12 EF30 EF46 Geschlecht EF47 
	GeburtsJahr EF49 Familienstand EF50 EF51 EF52 EF53 EF54 EF55 EF366 
	BRDBorn Zuzug EF367 JahrZuzug EF368 Auslaender EF369-EF370 SADoppelt 
	SA1 SA2 EF372 Eingebuergert EF373 JahrEinbuergerung EF374 SA3 MIG SA SA_erw
	EF358 ISVE ZuzugVE EF359 JahrZuzugVE EF360 AuslaenderVE EF361-EF362 
	SADoppeltVE SA1VE SA2VE EF363 EingebuergertVE EF364 JahrEinbuergerungVE 
	EF365 SA3VE MIGVE SAVE SA_erwVE EF350 IsME ZuzugME EF351 JahrZuzugME EF352 
	AuslaenderME EF353-EF354 SADoppeltME SA1ME SA2ME EF355 EingebuergertME 
	EF356 JahrEinbuergerungME EF382 SA3ME MIGME SAME SA_erwME berichtsjahr 
	AHRFQ Anzahl EF369_O EF374_O EF353_O  EF382_O EF361_O EF365_O);

	retain EF1 EF3 EF4 EF5 EF12 EF46 Geschlecht EF30 EF47 GeburtsJahr EF49 
	Familienstand EF50 EF51 EF52 EF53 EF54 EF55	EF366 BRDBorn Zuzug EF367 
	JahrZuzug EF368 Auslaender EF369-EF370 SADoppelt SA1 SA2 EF372 
	Eingebuergert EF373 JahrEinbuergerung EF374 SA3 MIG SA SA_erw EF358 
	ISVE ZuzugVE EF359 JahrZuzugVE EF360 AuslaenderVE EF361-EF362 
	SADoppeltVE SA1VE SA2VE EF363 EingebuergertVE EF364 JahrEinbuergerungVE 
	EF365 SA3VE MIGVE SAVE SA_erwVE EF350 IsME ZuzugME EF351 JahrZuzugME 
	EF352 AuslaenderME EF353-EF354 SADoppeltME SA1ME SA2ME EF355 
	EingebuergertME EF356 JahrEinbuergerungME EF382 SA3ME MIGME SAME SA_erwME
	berichtsjahr AHRFQ Anzahl EF369_O EF374_O EF353_O  EF382_O EF361_O EF365_O;


/* Datenquelle: Scientific Use File Mikrozensus 2005, Version 3 vom 05.12.2007,
   lokalen Dateinamen in < > eintragen */
	set mzjahr.<mz2005>;



/* ============== HARMONISIERUNG STAATSANGEHOERIGKEITEN ==============

Im SUF sind die Staatsaengehoerigkeiten unterschiedlich codiert bzw. aus 
Datenschutzgruenden vergroebert. Zur 2. Staatsangeh. (EF370) ist nur 
bekannt, ob diese vorhanden ist. In den Originaldaten sind die einzelnen
Staatsangehoerigkeiten ausgewiesen.
Die Typisierung der Staatsangehoerigkeit zum Migrationsstatus des 
Statistischen Bundesamtes (MIGS, MIG2005, SA_erw) kann deshalb nur 
naeherungsweise repliziert werden.*/

	* Sichern der Originalfassungen;
	EF369_O = EF369;
	EF374_O = EF374;
	EF353_O = EF353;
	EF382_O = EF382;
	EF361_O = EF361;
    	EF365_O = EF365;

	if EF369_O = 23 then EF369=1;
	if EF369_O = 30 then EF369=2;
	if EF369_O = 4  then EF369=3;  
	if EF369_O in (9,10,13,21,22,24,32,36,37) then EF369=3;
	if EF369_O = 26 then EF369=4;
	if EF369_O = 34 then EF369=5;
	if EF369_O = 3  then EF369=6;
	if EF369_O in (2,5,6,14,28,29,38) then EF369=7;
	if EF369_O in (40,41) then EF369=8;
	if EF369_O in (43,45,55) then EF369=9;
	if EF369_O in (47,48) then EF369=10;
	if EF369_O in (50,51,52) then EF369=11;
        
	if EF374_O = 23 then EF374=1;
	if EF374_O in (30,33,35) then EF374=2;
	if EF374_O in (4,9,10,13,21,22,32,36,37) then EF374=3;
	if EF374_O = 26 then EF374=4;
	if EF374_O = 34 then EF374=5;
	if EF374_O in (3,25) then EF374=6;
	if EF374_O in (2,14,29,38) then EF374=7;
	if EF374_O in (40,41,42) then EF374=8;
	if EF374_O in (43,45,55) then EF374=9;
	if EF374_O in (47,48,49) then EF374=10;
	if EF374_O in (50,51,52,53,54) then EF374=11;

	if EF353_O = 23 then EF353=1;
	if EF353_O = 30 then EF353=2;
	if EF353_O in (4,9,10,13,21,22,24,32,36,37) then EF353=3;
	if EF353_O = 26 then EF353=4;
	if EF353_O = 34 then EF353=5;
	if EF353_O = 3  then EF353=6;
	if EF353_O in (2,5,6,14,29,38,39) then EF353=7;
	if EF353_O in (40,41) then EF353=8;
	if EF353_O in (43,45,55) then EF353=9;
	if EF353_O in (47,48) then EF353=10;
	if EF353_O in (50,51,52) then EF353=11;

	if EF382_O = 23 then EF382=1;
	if EF382_O = 30 then EF382=2;
	if EF382_O = 37 then EF382=3;
	if EF382_O = 26 then EF382=4;
	if EF382_O = 34 then EF382=5;
	if EF382_O =  3 then EF382=6;
	if EF382_O in (5,6,38) then EF382=7;
	if EF382_O = 40 then EF382=8;
	if EF382_O = 55 then EF382=9;
	if EF382_O = 49 then EF382=10;
	if EF382_O = 54 then EF382=11;

	if EF361_O = 23 then EF361=1;
	if EF361_O = 30 then EF361=2;
	if EF361_O = 37 then EF361=3;
	if EF361_O = 26 then EF361=4;
	if EF361_O = 34 then EF361=5;
	if EF361_O =  3 then EF361=6;
	if EF361_O in (5,6,38) then EF361=7;
	if EF361_O = 40 then EF361=8;
	if EF361_O = 55 then EF361=9;
	if EF361_O = 49 then EF361=10;
	if EF361_O = 54 then EF361=11;

	if EF365_O = 23 then EF365=1;
	if EF365_O = 30 then EF365=2;
	if EF365_O in (13,37) then EF365=3;
	if EF365_O = 26 then EF365=4;
	if EF365_O = 34 then EF365=5;
	if EF365_O =  3 then EF365=6;
	if EF365_O in (5,6,38) then EF365=7;
	if EF365_O = 40 then EF365=8;
	if EF365_O = 55 then EF365=9;
	if EF365_O = 49 then EF365=10;
	if EF365_O = 54 then EF365=11;

/* Label fuer ef369 ef374 ef353 ef382 ef361 ef365 sa_erw migs* 
    0 = "Entfaellt (Deutsche(r) ohne weitere Staatsangehoerigkeit)"
    1 = "EU-25: PL Polen(23)"
    2 = "EU-25: SK, CZ, HU: Slowakei (30), Tschechische Republik(33), Ungarn(35)"
    3 = "EU-25: B, DK, EST, FIN, F,GR, IRL, I, LV, L, M, NL, A, P, S, E, GB, CY"
    4 = "EU Sonst: RUS: Russische Foederation(26)"
    5 = "EU Sonst: TR: Tuerkei(34)"
    6 = "EU Sonst: BG, RO: Bulgarien(03), Rumaenien(25)"
    7 = "EU Sonst: EU Sonst: BIH,SU, Y, IS, NDH, FL, N, CH, SB, MN"
    8 = "Afrika: Marokko(40), Sonstiges Nordafrika(41), Sonstiges Afrika(42)"
    9 = "Amerika, Uebrige Welt, Staatenlos: USA(43), Sonstiges Nordamerika(44), Mittelamerika und Karibik(45), Suedamerika(46), Uebrige Welt(55), Staatenlos(98)"
   10 = "Naher und Mittlerer Osten: Irak(47), Iran(48), Sonst ... (49)"
   11 = "Asien: Vietnam(50), Afghanistan(51), Sonst. Sued-/Suedostasien(52), China(53), Sonst. Ostasien(54)"
   99 = "Unbekannt"

Ausfuehrliche Label: 
[3] EU-25: Belgien(1), Daenemark(4), Estland(7), Finnland(8), Frankreich(9),
      Griechenland(10), Irland(11), Italien(13), Lettland(15), Litauen(17), 
      Luxemburg(18), Malta(19), Niederlande(21), Oesterreich(22,
      Portugal(24), Schweden(27), Slowenien(31), Spanien(32), 
      Vereinigtes Koenigreich(36), Zypern(37) 
[7] EU Sonst: Bosnien und Herzegowina(02), Ehemalige Sowjetunion(05), Ehemaliges Jugoslawien(06), 
      Island(12), Kroatien(14), Liechtenstein(16), Norwegen(20), Schweiz(28), 
      Serbien und Montenegro(29), Sonstiges Osteuropa(38), Sonstiges Europa(39) 
*/


/* Differenzierte Angaben zur 2. Staatsangehoerigkeit liegen nicht vor: 
   EF370 F100a 2. Staatsangehoerigkeit 
         1 "vorhanden"
         0 "Entfaellt (Deutscher, Auslaender mit nur einer Staatsangeh.)" 
   EF354 F106 2. ausl. Staatsangehoerigk.: Mutter
         1 "EU (...)" 
         2 "Uebrige Welt, Staatenlos"
         0 "Entfaellt"
   EF362 F113 2. ausl. Staatsangehoerigk.: Vater
         1 "vorhanden"
         0 "Entfaellt (Deutscher, Auslaender mit nur einer Staatsangeh.)"

Aus diesem Grund ist selbst nach Harmonisierung der Variablen mit 
Abweichungen der Staatsangehoerigkeit zum Migrationsstatus (MIGS*) zu den 
veroeffentlichten Verteilungen zu rechnen.

Im Folgenden werden wegen fehlender 2. Staatsangehoerigkeiten die Zuweisungen
zu den Variablen SA2* deaktiviert.
*/


/* ====================================================================
 1. Grundtypisierung des Migrationshintergrundes 
    Es werden zunaechst nur die Angaben der Person selbst zur 
    Typisierung verwendet. In den Jahren 2005 und 2009 werden die nicht 
    im Haushalt lebenden Eltern ebenfalls grundtypisiert. 
    Die erste Typisierung erfolgt nach Angaben zur Staatsangehoerigkeit 
    (deutsch / nicht-deutsch) und Geburtsland (Ausland / Inland).

 Ueberblick zu den nachfolgenden Zuweisungen:
 MIG: Migrationstypus:
  1. Stelle: Migrationstyp
     1=vertrieben;
     2=als Deutsche/r bzw. Spaetaussiedler zugewandert;
     3=eingebuergert;
     4=Auslaender/in;
  2. Stelle: Generation:
     1=im Ausland geboren;
     2=in Deutschland geboren
                                     
 vorlaeufige Codes MIG:
 11=Vertriebene vor 1950
 21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)
 22=Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung) 
 25=(Spaet-)Aussiedler (mit Einbuergerung)
 29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr 
 31=zugewanderte/r eingebuergerte/r Auslaender/in 
 32=nicht zugewanderte/r eingebuergerte/r Auslaender/in 
 41=zugewanderte/r Auslaender/in 
 42=nicht zugewanderte/r Auslaender/in
 77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler
 99=fehlende/unvollstaendige Angaben

 SA: aktuelle Staatsangehoerigkeit
 SA_erw: Erweiterte aktuelle Staatsangehoerigkeit
         [Basis fuer MIGS Staatsangehoerigkeit: Migrationsstatus]
         gewonnen aus   
           SA1 Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370)
           SA2 Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)
           SA3 Staatsangeh. vor Einbuerg./Zuzug als Spaetaussiedler
         nach folgenden Regeln: 
 SA_erw = 0   = deutsch (bei MIG=0, 11)
        = SA1 (bei Mig=41,42)
        = SA3 (bei Mig=21,25,29,31,32 und SA3<>.)
        = SA2 (bei MIG=21,25,29,31,32 und SA3=. und SA2<>.)
        = 99  (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder 
               bei MIG=77,99)
          [SAS-Sysmis in den Originaldaten sind oben bezeichnet mit: "."] */



/*	####### Geschlecht, Geburtsjahr und Familienstand der Person ####### */

	Geschlecht=ef46; 
	GeburtsJahr=ef47; 
	Familienstand=ef49; 
	Berichtsjahr=2005; 
	AHRFQ=EF952/0.7;          /* 70%-Substichprobe */
	Anzahl=1;

/*	####### Zuzug, Jahr des Zuzugs ####### */

	BRDBorn=ef366; 
	if BRDBorn=1 then Zuzug=0; 
	else if BRDBorn=8 then Zuzug=1; 
	else if BRDBorn=9 then Zuzug=9; 
	else Zuzug=9; 
	if ef367 = 1949 then JahrZuzug=1949; /* Zuzug vor 1950 */
	else if ef367 = 9999 then JahrZuzug=9; /* o.A. zum Zuzugsjahr */
	else if ef367 = 0    then JahrZuzug=0; /* kein Zuzugsjahr sinnvoll */
	else JahrZuzug=ef367; /* Zuzug 1950-200X */

	if (BRDBorn=1 and Jahrzuzug>9) then Zuzug=2;
	if (BRDBorn=8 and Jahrzuzug<10) then Jahrzuzug=9;

/*	####### Nationalitaet und Staatsangehoerigkeit ####### */

	if ef368=1 then do; /* nur deutsche SA */
		Auslaender=0; SADoppelt=0; SA1=0; SA2=.;
	end;
	else if ef368=2 then do; /* deutsche und auslaendische SA */
		Auslaender=0; SADoppelt=1; SA1=0; SA2=ef369;
	end;
	else do; /* nur auslaendische SA */
		Auslaender=1; SA1=ef369;
		if ef370=0 then do;
			SADoppelt=0; SA2=.;
		end;
		else do;
			SADoppelt=1; /* DEAKTIVIERT: SA2=ef370; */
		end;
	end;

/*	####### Einbuergerung und Staatsangehoerigkeit vor Einbuergerung ####### */

	if ef372=1 then do; /*eingebuergert */
		Eingebuergert=1; 
		if ef373 = 0 then JahrEinbuergerung=9; /* k.A. Einbuergerungsjahr */
		else JahrEinbuergerung=ef373;
		if ef374 = 0 then SA3=.; /* SA vor Einbuergerung nicht angegeben */
		else SA3=ef374;
	end;
	else do; /* nicht eingebuergert */
		Eingebuergert=0; JahrEinbuergerung=9; SA3=0;
	end;


/*	####### Grundtypisierung des Migrationshintergrundes ####### */


	/*A) im Ausland geboren*/
	if BRDBorn=8 then do;
		if Auslaender=1 then do; /* A1) Auslaender, im Ausland geboren */
			MIG=41; SA=SA1; SA_erw=SA1; /* SA und SA_erw: auslaendische SA */
		end;
		else do;
			if Eingebuergert=1 then do; /* A2) Eingebuergerte/r, im Ausland geboren */
				MIG=31; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, wenn fehlt, 2. SA */
				if SA3=. then SA_erw=SA2; /* ansonsten 'missing' */
				if SA_erw=. then SA_erw=99; 
			end;
			else do; /* wenn Deutsche/r */
				if Jahrzuzug=1949 then do; /* A3) Vertriebener vor 1950 */
					MIG=11; SA=SA1; SA_erw=SA1; /* SA_erw: SA1 */
				end;
				else if Jahrzuzug>1949 then do; /* A4) als Deutscher/r zugewandert */
					MIG=21; SA=SA1; SA_erw=SA1; /* SA_erw: SA1, ggf. SA2 */
					if SA2 ne . then SA_erw=SA2; 
				end;
				else if JahrZuzug=9 then do;
		/*	Zuzug ohne Angabe zum Jahr d.h.kann Vertriebener oder als Deutscher/r zugewandert sein 
			Annahme 1: wenn nach 1949 geboren, als Deutscher/r zugewandert;
			Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener; 
			Annahme 3: sonst Zuzug Deutscher ohne Datumsangabe 29 */
		
					/* Annahme 1: */
					if GeburtsJahr>1949 then do; 
						MIG=21; SA=SA1; SA_erw=SA1; /* SA_erw: SA1, ggf. SA2 */
						if SA2 ne . then SA_erw=SA2; 
					end;
					/* Annahme 2: */
					else if (SADoppelt=0 and SA1=0) then do; 
						MIG=11; SA=SA1; SA_erw=SA1; 
					end;
					/* Annahme 3: */
					else do; 
						MIG=29; SA=SA1; SA_erw=SA1; /* SA_erw: SA1, ggf. SA2 */
						if SA2 ne . then SA_erw=SA2; 
					end;
				end;
				else do; /* Jahrzuzug=0 */
		/*	Zuzug ohne Angabe zum Jahr d.h. kann Vertriebener oder als Deutscher/r zugewandert sein 
			Annahme 1: wenn nach 1949 geboren, als Deutscher/r zugewandert;
			Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener; 
			Annahme 3: sonst Zuzug Deutscher ohne Datumsangabe 29 
			ggf. redundant */
		
					/* Annahme 1: */
					if GeburtsJahr>1949 then do; 
						MIG=21; SA=SA1; SA_erw=SA1; /* SA_erw: SA1, ggf. SA2 */
						if SA2 ne . then SA_erw=SA2; 
					end;
					/* Annahme 2: */
					else if (SADoppelt=0 and SA1=0) then do; 
						MIG=11; SA=SA1; SA_erw=SA1; 
					end;
					/* Annahme 3: */
					else do; 
						MIG=29; SA=SA1; SA_erw=SA1; /* SA_erw: SA1, ggf. SA2 */
						if SA2 ne . then SA_erw=SA2; 
					end;
				end;
			end;
		end;
	end;

/*	B) im Inland geboren: Deutsche/Migranten der 2. oder spaeteren Generation */
	else if BRDBorn=1 then do;
		if Auslaender=1 then do; /* b1) Auslaender, in Deutschland geboren */
			MIG=42; SA=SA1; SA_erw=SA1; /* SA und SA_erw: auslaendische SA */
		end;
		else do;
			if Eingebuergert=1 then do; /* b2) Eingebuergerte/r, in Deutschland geboren */
				MIG=32; SA=SA1; SA_erw=SA3;  /* SA_erw: SA vor Einbuergerung, */
				if SA3=. then SA_erw=SA2; /* wenn fehlt, 2. SA */ 
				if SA_erw=. then SA_erw=99; /* ansonsten 'missing' */
			end;
			else do; /* b3) in Deutschland geborener Deutscher */
				Mig=77; SA=SA1; if SA3 ne . then SA_erw=SA3; 
			end;
		end;
	end;
	else if BRDBorn=9 then do; /* keine Auskunft; kommt wohl nicht vor */
		Mig=99;SA=SA1; if SA3 ne . then SA_erw=SA3; 
	end;

/*	--------------------------------------------------------------------------- */
/*	Hier folgt der Code zur Typisierung des Migrationshintergrundes der nicht 
	im Haushalt lebenden Eltern fuer die Jahre 2005 und 2009 */


/*	Angaben zum Vater: Nomenklatur wie oben mit Suffix VE (Vater extern) 
	Bearbeitung nur, wenn Vater nicht im Haushalt lebt, d.h. wenn EF357='8' */

/*	####### Zuzug, Jahr des Zuzugs des Vaters ####### */
/*	ZuzugVE:   
		0=kein Zuzug; 
		1=nach 1960 zugezogen = foreign born; 
		9=k.A. 
	JahrZuzugVE:   
		1960-2006= jeweiliges Jahr; 
		9=k.A. */

/*	Vorbelegung: keine Angaben zu Vater im HH */
	IsVE=0; SA1VE=0; SA2VE=.;

	if EF357=8 then do;	/* Vater lebt nicht im Haushalt */
		IsVE=1; ZuzugVE=ef358; 
		if ZuzugVE=8 then ZuzugVE=0;

		if ef359 = 9999 then JahrZuzugVE=9; /* k.A. zum Zuzugsjahr */
		else if ef359 = 0 then do; /* kein Zuzug */
			ZuzugVE=0; JahrZuzugVE=9; 
		end;
		else JahrZuzugVE=ef359; /* Zuzug 1960-200X */

/*	####### Nationalitaet und Staatsangehoerigkeit des Vaters ####### */


		if ef360=1 then do; /* nur deutsche SA */
			AuslaenderVE=0; SADoppeltVE=0; SA1VE=0; SA2VE=.;
		end;
		else if ef360=2 then do; /* deutsche und auslaendische SA */
			AuslaenderVE=0; SADoppeltVE=1; SA1VE=0; SA2VE=ef361;
		end;
		else if ef360=8 then do; /* nur auslaendische SA oder SAs */
			AuslaenderVE=1; SA1VE=ef361;
			if ef362=0 then do;
				SADoppeltVE=0; SA2VE=.;
			end;
			else do;
				SADoppeltVE=1; SA2VE=ef362;
			end;
		end;
		else do; /* 'entfaellt' Auspraegung (EF360=' ') */
			AuslaenderVE=0; SADoppeltVE=0; SA1VE=0; SA2VE=.;
		end;

/*	####### Einbuergerung und Staatsangehoerigkeit vor Einbuergerung des Vater ####### */

		if ef363=1 then do; /* wenn eingebuergert... */
			EingebuergertVE=1;
			if ef364 = 0 then JahrEinbuergerungVE=9; /* k.A. zu Einbuergerungsjahr */
			else if ef364 = 9999 then JahrEinbuergerungVE=9; /* k.A. zu Einbuergerungsjahr */
			else JahrEinbuergerungVE=ef364;
			if ef365 = 0 then SA3VE=.; /* k.A. zu SA vor Einbuergerung */
			else SA3VE=ef365; /* SA vor Einbuergerung */
		end;
		else do; /* wenn nicht eingebuergert... */
			EingebuergertVE=0; JahrEinbuergerungVE=9; SA3VE=0;
		end;

/*	####### Grundtypisierung des Migrationshintergrundes des Vaters ####### */
/*	MIGVE:
		11=Vertriebene vor 1950;
		21=als Deutsche/r zugewandert;
		29=als Deutsche/r zugewandert k.A. zum Zuzugsjahr (21 gleichgestellt);
		31=eingebuergerte/r zugewanderte/r Auslaender/in;
		32=eingebuergerte/r nicht zugewanderte/r Auslaender/in;
		41=zugewanderte/r Auslaender/in;
		42=nicht zugewanderte/r Auslaender/in;
		77=uneindeutig ob deutsch, vertrieben oder als Deutsche/r zugewandert 
		99=fehlende/unvollstaendige Angaben 
	SAVE: Vater extern: aktuelle Staatsangehoerigkeit

	SA_erwVE: Vater extern: erweiterte aktuelle Staatsangehoerigkeit
		gewonnen aus SA1 - SA3 nach folgenden Regeln:
		0=deutsch (bei MIG=0, 11);
		=SA1 (bei Mig=41, 42);
		=SA3 (bei Mig=31, 32 und SA3<>.);
		=SA2 (bei MIG=21, 29 oder bei Mig=31, 32 und SA3=.)
		=99 (bei MIG=21,29 und SA2=. oder bei Mig=31, 32 und SA3=.
			oder bei MIG=77,99)	*/

/*	A) wenn Vater zugezogen... */
		if ZuzugVE=1 then do;
			if AuslaenderVE=1 then do; /* A1) Auslaender, im Ausland geboren */
				MIGVE=41; SAVE=SA1VE; SA_erwVE=SA1VE; /* SA und SA_erw: auslaendische SA */
			end;
			else do;
				if EingebuergertVE=1 then do; /* A2) Eingebuergerte/r, im Ausland geboren */
					MIGVE=31; SAVE=SA1VE; SA_erwVE=SA3VE;  /* SA_erw: SA vor Einbuergerung, wenn fehlt, 2. SA */
					if SA3VE=. then SA_erwVE=SA2VE; /* ansonsten 'missing' */
					if SA_erwVE=. then SA_erwVE=99; 
				end;
				else do; /* wenn Deutsche/r */
					if JahrzuzugVE>=1950 then do; /* A3) als Deutscher/r zugewandert */
						MIGVE=21; SAVE=SA1VE; SA_erwVE=SA1VE; /* SA_erw: SA1, ggf. SA2 */
						if SA2VE ne . then SA_erwVE=SA2VE; 
					end;
					else if JahrZuzugVE=9 then do;
						MIGVE=29; SAVE=SA1VE; SA_erwVE=SA1VE; /* SA_erw: SA1, ggf. SA2 */
						if SA2VE ne . then SA_erwVE=SA2VE; 
					end;
				end;
			end;
		end;
/*	wenn Vater nicht zugezogen, liegen keine Angaben zu Migration vor */
		else do;
			MigVE=77; /* uneindeutig: im Ausland verblieben oder lebte bereits hier */
			SA1VE=0; SAVE=SA1VE; SA_erwVE=0;
			if SA3VE ne . then SA_erwVE=SA3VE; 
		end;
	end; /* ... Ende von 'if EF357='8' then do;'	*/

/*	Angaben zur Mutter: Nomenklatur wie oben mit Suffix ME (Mutter extern) 
	Bearbeitung nur, wenn Mutter nicht im Haushalt lebt, d.h. wenn EF349='8' */

/*	####### Zuzug, Jahr des Zuzugs der Mutter ####### */
/*	ZuzugME:   
		0=kein Zuzug; 
		1=nach 1960 zugezoen = foreign born; 
		9=k.A. 
	JahrZuzugME:   
		1960-2006= jeweiliges Jahr; 
		9=k.A. */

	/* Vorbelegung: keine Angaben zu Mutter im HH */
	IsME=0; SA1ME=0; SA2ME=.; 
	if EF349=8 then do; /* Mutter lebt nicht im Haushalt */	
		IsME=1; ZuzugME=ef350; 
		if ZuzugME=8 then ZuzugME=0;

		if ef351 = 9999 then JahrZuzugME=9; /* k.A. zum Zuzugsjahr */
		else if ef351 = 0 then do; /* kein Zuzug */
			ZuzugME=0; JahrZuzugME=9; 
		end;
		else JahrZuzugME=ef351; /* Zuzug 1960-200X */

/*	####### Nationalitaet und Staatsangehoerigkeit der Mutter ####### */

		if ef352=1 then do; /* nur deutsche SA */
			AuslaenderME=0; SADoppeltME=0; SA1ME=0; SA2ME=.;
		end;
		else if ef352=2 then do; /* deutsche und auslaendische SA */
			AuslaenderME=0; SADoppeltME=1; SA1ME=0; SA2ME=ef353;
		end;
		else if ef352=8 then do; /* nur auslaendische SA oder SAs */
			AuslaenderME=1; SA1ME=ef353;
			if ef354=0 then do;
				SADoppeltME=0; SA2ME=.;
			end;
			else do;
				SADoppeltME=1; SA2ME=ef354;
			end;
		end;
		else do; /* entfaellt Auspraegung */
			AuslaenderME=0; SADoppeltME=0; SA1ME=0; SA2ME=.;
		end;

/*	####### Einbuergerung und Staatsangehoerigkeit vor Einbuergerung der Mutter ####### */

		if ef355=1 then do; /* wenn eingebuergert... */
			EingebuergertME=1; 
			if ef356 = 0 then JahrEinbuergerungME=9; /* k.A. zu Einbuergerungsjahr */
			else if ef356 = 9999 then JahrEinbuergerungME=9; /* k.A. zu Einbuergerungsjahr */
			else JahrEinbuergerungME=ef356;
			if ef382 = 0 then SA3ME=.; /* k.A. zu SA vor Einbuergerung */
			else SA3ME=ef382; /* SA vor Einbuergerung */
		end;
		else do; /* wenn nicht eingebuergert... */
			EingebuergertME=0; JahrEinbuergerungME=9; SA3ME=0;
		end;

/*	####### Grundtypisierung des Migrationshintergrundes der Mutter ####### */
/*	MIGME:
		21=als Deutsche/r zugewandert;
		29=als Deutsche/r zugewandert k.A. zum Zuzugsjahr (21 gleichgestellt);
		31=eingebuergerte/r zugewanderte/r Auslaender/in;
		41=zugewanderte/r Auslaender/in;
		77=uneindeutig ob deutsch, vertrieben oder als Deutsche/r zugewandert 
	SAME: Mutter extern: aktuelle Staatsangehoerigkeit

	SA_erwME: Mutter extern: erweiterte aktuelle Staatsangehoerigkeit
		gewonnen aus SA1 - SA3 nach folgenden Regeln:
		0=deutsch (bei MIG=0, 11);
		=SA1 (bei Mig=41);
		=SA3 (bei Mig=31 und SA3<>.);
		=SA2 (bei MIG=21, 29 oder bei Mig=31 und SA3=.)
		=99 (bei MIG =21,29 und SA2=. oder bei Mig=31 und SA3=.
			oder bei MIG=77)	*/

/*	A)wenn Mutter zugezogen... */
		if ZuzugME=1 then do;
			if AuslaenderME=1 then do; /* A1) Auslaender, im Ausland geboren */
				MIGME=41; SAME=SA1ME; SA_erwME=SA1ME; /* SA und SA_erw: auslaendische SA */
			end;
			else do;
				if EingebuergertME=1 then do; /* A2) Eingebuergerte/r, im Ausland geboren */
					MIGME=31; SAME=SA1ME; SA_erwME=SA3ME;  /* SA_erw: SA vor Einbuergerung, wenn fehlt, 2. SA */
					if SA3ME=. then SA_erwME=SA2ME; /* ansonsten 'missing' */
					if SA_erwME=. then SA_erwME=99; 
				end;
				else do; /* wenn Deutsche/r */
					if JahrzuzugME>=1950 then do; /* A3) als Deutscher/r zugewandert */
						MIGME=21; SAME=SA1ME; SA_erwME=SA1ME; /* SA_erw: SA1, ggf. SA2 */
							if SA2ME ne . then SA_erwME=SA2ME; 
					end;
					else if JahrZuzugME=9 then do;
						MIGME=29; SAME=SA1ME; SA_erwME=SA1ME; /* SA_erw: SA1, ggf. SA2 */
							if SA2ME ne . then SA_erwME=SA2ME; 
					end;
				end;
			end;
		end;
/*	wenn Mutter nicht zugezogen, liegen keine Angaben zu Migration vor */
		else do;
			MigME=77; /* uneindeutig: im Ausland verblieben oder lebte bereits hier */
			SAM1E=0; SAME=SAM1E; SA_erwME=0;
			if SA3ME ne . then SA_erwME=SA3ME; 
		end;
	end; /* ... Ende von 'if EF349='8' then do;'	*/

run;


