/* migstat05_sas.zip: 06 Endtypisierung Grosseltern 2005.sas

 3. Endtypisierung Grosseltern */


OPTIONS NOFMTERR; RUN;   /* ohne Formate */

libname mzjahr '<Arbeitsverzeichnis'>;


/*  Auswahl des grundtypisierten Materials fuer alle als Grosseltern 
	identifizierten Personen */
proc sql;
	create table mzjahr.GrosselternTypTmp as
	select a.*
	from mzjahr.MZTypisiert as a, mzjahr.Grosseltern as b
	where a.ef1=b.ef1 and a.ef3=b.ef3 and a.ef4=b.ef4 
		and a.ef12=b.ef12 and a.ef5=b.ef5;
quit;

data mzjahr.GrosselternTypisiert 
		(KEEP=EF1 ef3 ef4 ef5 EF12 
		MIG SA1 SA2 SA3 SA SA_erw 
  	    	ISVE MIGV SAV SA_erwV 
		ISME MIGM SAM SA_erwM)
	ErrorGross (Keep=EF1 EF3 EF4 EF5 EF12 p v m kennung);
	retain EF1 EF3 EF4 EF5 EF12 MIG SA1 SA2 SA3 SA SA_erw 
	       ISVE MIGV SAV SA_erwV ISME MIGM SAM SA_erwM;
/*	Quelle ist die Datei 'GrosselternTypTmp' */
	set mzjahr.GrosselternTypTmp; 

/*	--------------------------------------------------------------------------- */
/*	Hier folgt der Code zur Verarbeitung der externen Angaben zu den nicht 
	im Haushalt lebenden Eltern fuer die Jahre 2005 und 2009 */

if Berichtsjahr in (2005, 2009) then do;

/*	------------------------------------------------------------------------ */
/*	'Converse' enthaelt die Abbildungsvorschriften zur Ermittlung des
	Migrationsstatus aus den Werten MIG, MIGV und MIGM.
	Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
	vorlaeufigen Migrationsstatus wird der resultierende endgueltige
	Migrationsstatus zurueckgegeben. Die Variable Kennung enthaelt den 
	Fallidentifikator, der die Abbildungsvorschrift eindeutig identifiziert */

/*	Vorbelegen der Werte und Definieren der Hash-Table */
	if _n_=1 then do;
		_mig_=0; _migv_=0; _migm_=0; migneu=0; Kennung=0;
		declare hash converse(dataset: "mzjahr.converse"); /* ex: conversion_2011.xls */
		converse.defineKey("_mig_"); 
		converse.defineKey("_migv_"); 
		converse.defineKey("_migm_"); 
		converse.defineData("migneu");	
		converse.defineData("kennung");	
		converse.defineDone();
	end;

/*	Zusammenfuehren der Angaben zu Grosseltern in und ausserhalb des Haushalts */
/*	Bei Grosseltern liegen nur externe Angaben vor */

	MIGV=MIGVE; SA1V=SA1VE; SA2V=SA2VE; SA3V=SA3VE; SAV=SAVE; SA_erwV=SA_erwVE; 
	MIGM=MIGME; SA1M=SA1ME; SA2M=SA2ME; SA3M=SA3ME; SAM=SAME; SA_erwM=SA_erwME; 

/*	nur im Inland Geborene werden der Konversions-Prozedur unterworfen */
	if not (MIG in (11, 21, 29, 31, 41)) then do; 

/*	durch Konversion koennen fuer Vater und Mutter neue Mig-Werte entstanden sein,
	fuer die die Konversionstabelle keine Abbildungvorschrift enthaelt. Fuer diese Werte
	werden kompatible, in der Konversionstabelle definierte Ersatzwerte eingestellt */
		p=MIG;
		v=MIGV; If MIGV=0 then v=99; if MIGV in (22,23) then v=21;
		m=MIGM; If MIGM=0 then m=99; if MIGM in (22,23) then m=21;

/*	In Konversiontabelle Abbildung fuer Mig-Werte nachschlagen */
		_ec2_=converse.find(key:p, Key:v, Key:m);
		if _ec2_ then do; /* wenn nicht gefunden... */
/*	in Fehlerdatei die nicht-definierte Kombination von Mig, MigV, MigM ausgeben */
			output ErrorGross;
		end; 
		else do; /* wenn gefunden (hoffentlich)... */
			MIG=migneu; 
		end;

/*	SA_erw durch aussagekraeftigen Vatereintrag ergaenzen, sofern noetig und moeglich */
		if ((SA_erw in (0,99)) and (SA_erwV not in (0,99))) then SA_erw=SA_erwV;

/*	SA_erw durch aussagekraeftigen Muttereintrag ergaenzen, sofern noch immer noetig 
	und moeglich */
		if ((SA_erw in (0,99)) and (SA_erwM not in (0,99))) then SA_erw=SA_erwM;
	end;

/*	im Ausland geborene Migranten direkt ausgegeben */
	else do; 
		if MIG=11 then Kennung=1;
		else if MIG=21 then Kennung=2;
		else if MIG=29 then Kennung=3;
		else if MIG=31 then Kennung=4;
		else if MIG=41 then Kennung=5;
	end;


end; /* ... if Berichtsjahr in (2005, 2009) then do; */

output mzjahr.GrosselternTypisiert;
run;
